@@ -1,40 +1,68 @@
-__version__ = "0.1.1"
+__version__ = "0.2.1"
 
 # module of "core"
 from npbrain import core
+
+from npbrain.core import ode
+from npbrain.core.ode import ode_generator
+
+from npbrain.core import sde
+from npbrain.core.sde import sde_generator
+
 from npbrain.core import monitor
 from npbrain.core.monitor import *
+
 from npbrain.core import network
 from npbrain.core.network import *
+
 from npbrain.core import neuron
 from npbrain.core.neuron import *
-from npbrain.core import ode
-from npbrain.core.ode import *
-from npbrain.core import sde
-from npbrain.core.sde import *
+
 from npbrain.core import synapse
 from npbrain.core.synapse import *
 
 
 # module of "neurons"
 from npbrain import neurons
+
+from npbrain.neurons import HH_model
+from npbrain.neurons.HH_model import *
+
 from npbrain.neurons import LIF_model
 from npbrain.neurons.LIF_model import *
 
+from npbrain.neurons import Izhikevich_model
+from npbrain.neurons.Izhikevich_model import *
+
 
 # module of "synapse"
 from npbrain import synapses
+
+from npbrain.synapses import AMPA_synapses
+from npbrain.synapses.AMPA_synapses import *
+
+from npbrain.synapses import GABA_synapses
+from npbrain.synapses.GABA_synapses import *
+
+from npbrain.synapses import gap_junction
+from npbrain.synapses.gap_junction import *
+
+from npbrain.synapses import NMDA_synapses
+from npbrain.synapses.NMDA_synapses import *
+
 from npbrain.synapses import ordinary_synapses
 from npbrain.synapses.ordinary_synapses import *
 
+from npbrain.synapses import short_term_plasticity
+from npbrain.synapses.short_term_plasticity import *
+
 
 # module of "utils"
 from npbrain import utils
-from npbrain.utils import connection
-from npbrain.utils.connection import *
+from npbrain.utils import conn
+from npbrain.utils import input_factory
+from npbrain.utils import vis
+
 from npbrain.utils import helper
 from npbrain.utils.helper import *
-from npbrain.utils import input_factory
-from npbrain.utils.input_factory import *
-from npbrain.utils import visualization
-from npbrain.utils.visualization import *
+
