@@ -1,16 +1,19 @@
 import types
 import functools
+import numpy as np
 
-from npbrain.profile import get_backend
+from npbrain.profile import is_numba_bk
 from npbrain.profile import get_numba_profile
 
-if get_backend().startswith('numba'):
+if is_numba_bk():
     import numba as nb
 
 __all__ = [
     'check_params',
     'jit_function',
     'jit_lambda',
+    'autojit',
+    'clip',
     'copy_func',
     'Dict',
     'default_dict',
@@ -19,20 +22,134 @@ __all__ = [
 
 
 def check_params(kwargs):
+    """Check the ``kwargs`` parameters.
+
+    If there are more parameters left, it means the users give the
+    wrong parameters.
+
+    Parameters
+    ----------
+    kwargs : dict
+        Parameters.
+    """
     assert len(kwargs) == 0, "No arguments about: {}".format(list(kwargs.keys()))
 
 
 def jit_function(f):
+    """Generate ``numba`` JIT functions.
+
+    Parameters
+    ----------
+    f : callable
+        The function.
+
+    Returns
+    -------
+    callable
+        JIT function.
+    """
     profile = get_numba_profile()
     return nb.jit(f, **profile)
 
 
 def jit_lambda(f):
+    """Generate ``numba`` JIT lambda functions.
+
+    Parameters
+    ----------
+    f : callable
+        The lambda function.
+
+    Returns
+    -------
+    callable
+        JIT function.
+    """
     profile = get_numba_profile()
     profile['cache'] = False
     return nb.jit(f, **profile)
 
 
+def is_lambda_function(func):
+    """Check whether the function is a ``lambda`` function. Comes from
+    https://stackoverflow.com/questions/23852423/how-to-check-that-variable-is-a-lambda-function
+
+    Parameters
+    ----------
+    func : callable function
+        The function.
+
+    Returns
+    -------
+    bool
+        True of False.
+    """
+    return isinstance(func, types.LambdaType) and func.__name__ == "<lambda>"
+
+
+def autojit(func):
+    """Format user defined functions.
+
+    Parameters
+    ----------
+    func : callable
+
+    Returns
+    -------
+    callable
+        function.
+    """
+    if is_numba_bk():
+        if is_lambda_function(func):
+            func = jit_lambda(func)
+        else:
+            func = jit_function(func)
+    return func
+
+
+def clip(a, a_min, a_max):
+    """Reproduce the ``clip`` function in NumPy.
+
+    Clip (limit) the values in an array.
+
+    Given an interval, values outside the interval are clipped to
+    the interval edges.  For example, if an interval of ``[0, 1]``
+    is specified, values smaller than 0 become 0, and values larger
+    than 1 become 1.
+
+    Equivalent to but faster than ``np.maximum(a_min, np.minimum(a, a_max))``.
+    No check is performed to ensure ``a_min < a_max``.
+
+    Parameters
+    ----------
+    a : array_like
+        Array containing elements to clip.
+    a_min : scalar or array_like or None
+        Minimum value. If None, clipping is not performed on lower
+        interval edge. Not more than one of `a_min` and `a_max` may be
+        None.
+    a_max : scalar or array_like or None
+        Maximum value. If None, clipping is not performed on upper
+        interval edge. Not more than one of `a_min` and `a_max` may be
+        None. If `a_min` or `a_max` are array_like, then the three
+        arrays will be broadcasted to match their shapes.
+
+    Returns
+    -------
+    clipped_array : ndarray
+        An array with the elements of `a`, but where values
+        < `a_min` are replaced with `a_min`, and those > `a_max`
+        with `a_max`.
+    """
+    a = np.maximum(a, a_min)
+    a = np.minimum(a, a_max)
+    return a
+
+
+if is_numba_bk():
+    clip = autojit(clip)
+
+
 def copy_func(f):
     """Based on http://stackoverflow.com/a/6528148/190597 (Glenn Maynard)"""
     g = types.FunctionType(f.__code__, f.__globals__,
